* **id**: The unique identifier for the record.
* **created_at**: When was the record created?
* **updated_at**: When was the record last updated?
* **email**: Current email address.
* **given_name**: Given name.
* **family_name**: Family name.
* **telephone**: Telephone number - typically a mobile to receive text messages.
* **role**: Assigned user role.
* **default_output_storage_period**: The default number of days for which outputs are stored.
* **time_zone**: Time zone.
* **locale**: Locale.
* **units**: Preferred measurement units.
* **notification_service_status**: How will notifications will be sent for service status updates?
* **notification_account**: How will notifications will be sent for account updates?
* **notification_processing_chain**: How will notifications will be sent for processing chain execution?
* **notification_new_features**: How will notifications will be sent for new features?
* **notification_contact**: How will notifications will be sent for contact requests?
* **last_request_at**: The last time a request was made.
